@@ -69,9 +69,13 @@ new S3ToStepFunction(scope: Construct, id: string, props: S3ToStepFunctionProps)
 | **Name**     | **Type**        | **Description** |
 |:-------------|:----------------|-----------------|
 |stateMachine|[`sfn.StateMachine`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-stepfunctions.StateMachine.html)|Returns an instance of sfn.StateMachine created by the construct|
+|stateMachineLogGroup|[`logs.LogGroup`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-logs.LogGroup.html)|Returns an instance of the LogGroup created by the construct for StateMachine|
 |cloudwatchAlarms|[`cloudwatch.Alarm[]`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-cloudwatch.Alarm.html)|Returns a list of cloudwatch.Alarm created by the construct|
 |s3Bucket|[`s3.Bucket`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.Bucket.html)|Returns an instance of the s3.Bucket created by the construct|
+|s3LoggingBucket?|[`s3.Bucket`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.Bucket.html)|Returns an instance of s3.Bucket created by the construct as the logging bucket for the primary bucket.|
 |cloudtrail|[`cloudtrail.Trail`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-cloudtrail.Trail.html)|Returns an instance of the cloudtrail.Trail created by the construct|
+|cloudtrailBucket|[`s3.Bucket`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.Bucket.html)|Returns an instance of the s3.Bucket created by the construct for CloudTrail|
+|cloudtrailLoggingBucket|[`s3.Bucket`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.Bucket.html)|Returns an instance of s3.Bucket created by the construct as the logging bucket for the primary CloudTrail bucket.|
 
 ## Default settings
 
@@ -81,6 +85,7 @@ Out of the box implementation of the Construct without any override will set the
 
 * Configure Access logging for S3 Bucket
 * Enable server-side encryption for S3 Bucket using AWS managed KMS Key
+* Enforce encryption of data in transit
 * Turn on the versioning for S3 Bucket
 * Don't allow public access for S3 Bucket
 * Retain the S3 Bucket when deleting the CloudFormation stack
@@ -122,6 +127,7 @@ from ._jsii import *
 import aws_cdk.aws_cloudtrail
 import aws_cdk.aws_cloudwatch
 import aws_cdk.aws_events
+import aws_cdk.aws_logs
 import aws_cdk.aws_s3
 import aws_cdk.aws_stepfunctions
 import aws_cdk.core
@@ -184,11 +190,31 @@ class S3ToStepFunction(
     def state_machine(self) -> aws_cdk.aws_stepfunctions.StateMachine:
         return jsii.get(self, "stateMachine")
 
+    @builtins.property
+    @jsii.member(jsii_name="stateMachineLogGroup")
+    def state_machine_log_group(self) -> aws_cdk.aws_logs.LogGroup:
+        return jsii.get(self, "stateMachineLogGroup")
+
     @builtins.property
     @jsii.member(jsii_name="cloudtrail")
     def cloudtrail(self) -> typing.Optional[aws_cdk.aws_cloudtrail.Trail]:
         return jsii.get(self, "cloudtrail")
 
+    @builtins.property
+    @jsii.member(jsii_name="cloudtrailBucket")
+    def cloudtrail_bucket(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
+        return jsii.get(self, "cloudtrailBucket")
+
+    @builtins.property
+    @jsii.member(jsii_name="cloudtrailLoggingBucket")
+    def cloudtrail_logging_bucket(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
+        return jsii.get(self, "cloudtrailLoggingBucket")
+
+    @builtins.property
+    @jsii.member(jsii_name="s3LoggingBucket")
+    def s3_logging_bucket(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
+        return jsii.get(self, "s3LoggingBucket")
+
 
 @jsii.data_type(
     jsii_type="@aws-solutions-constructs/aws-s3-step-function.S3ToStepFunctionProps",
